#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-IyFIeGNDdnVINbVfVZcb7j
key:                  openssl-streams-1.2.3.0-IyFIeGNDdnVINbVfVZcb7j
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  e3ed5e5556f3a4bbe22904d12363a866
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-IyFIeGNDdnVINbVfVZcb7j
depends:
    HsOpenSSL-0.11.7.10-72aBGaewYjbEhtZXYKzg7c base-4.18.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-h4AeGCmO0kLAw7dl36WEj
    network-3.1.4.0-FBuTdTHZ29uBPcO3Y238RO

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

